# Keno API - Unofficial Keno API

## What is it?
kenoAPI is Python package that provides data from the offical [Keno](https://www.keno.com.au/) website.

## Main Features
* Monitor Draws in real time.
* Real-time Jackpot's.
* Hot And Cold Numbers

## Where to get it
```
pip install kenoAPI
```

## Dependencies
* [Requests](https://github.com/psf/requests)
* [Pandas](https://github.com/pandas-dev/pandas)
* Datetime

## License
[BSD 3](https://github.com/JGolafshan/KenoAPI/blob/main/LICENSE)

This software has been developed for educational use only. Use at your own risk.

## Documentation
[Wiki / Documentation](https://github.com/JGolafshan/KenoAPI/wiki)
